@@ -246,10 +246,3 @@ def token_refresh():
     # from sys import path
 
     ChatAPI().get_token()
-
-
-def funcname(foo):
-    """
-    docstring
-    """
-    print(foo)
